Crate stormath

Crate stormath 

Collection of common mathematical utility functions.

The library is developed in parallel to, and for, the Stormbird library. The functions available is closely connected to what is needed here. However, the implementation of the functionality in this crate is such that it may also be useful in other contexts. It is therefore kept as a separate crate.

Modules

array_generation
Helper functions to generate arrays of numbers.
consts
Different constant. Defined so that it should be easy load these with the Float type alias
error
General error types in the library.
finite_difference
Functions to perform finite difference calculations
integration
Numerical integration functions
interpolation
Interpolation functions
matrix
A matrix structure that comes with the standard operations for matrices
optimize
Optimization algorithms
rigid_body_motion
General functionality to represent rigid body motion. That is, a data structure and methods for storing and relating translation and rotation.
smoothing
Smoothing functions for 1D data.
solvers
Numerical solvers, such as root-finding algorithms.
spatial_vector
Functionality related to vectors representing spatial quantities.
special_functions
Special functions means functions that are well known, but which otherwise are just functions that produce a value based on some input. The name special functions is inspired by the the scipy library.
statistics
Functions that compute statistical properties of vectors
type_aliases
Type aliase to easy switch between different floating point number represntations