Module spatial_vector

Module spatial_vector 

Functionality related to vectors representing spatial quantities, e.g., position, velocity and acceleration.

The data structure does not assume anything about the number of dimensions, meaning it can be used both for 2D and 3D vectors.

Modules

geometry_functions
iterators
operators
serde_implementations
transformations
Geometry transformations, such as rotation and translation
vector_math

Structs

SpatialVector
A 2D or 3D vector with typical geometric functions implemented

Constants

DATA_SIZE
VECTOR_LENGTH